@@ -1,6 +1,6 @@
 /*
     Text maid
-    copyright (c) 1998-2003 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2004 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /******************************************************************************
 *                                                                             *
-* 漢字関数群                                                                  *
+* ja:キャラクターセット関数群                                                 *
 *                                                                             *
 ******************************************************************************/
 gsize charset_leng[256] = {
@@ -37,83 +37,89 @@ gsize charset_leng[256] = {
 guchar charset_space[] = {3, 0xE3, 0x80, 0x80, 0};
 
 
-/*  フォントの幅と高さを取得する
+/*  ja:フォントの幅と高さを取得する
       layout,レイアウト
        width,幅
       height,高さ
     font_buf,バッファ                                                       */
 void
-charset_size (PangoLayout *layout, gint *width, gint *height, guint8 *font_buf)
+charset_size (PangoLayout *layout,
+              gint        *width,
+              gint        *height,
+              guint8      *font_buf)
 {
-    int w, h;
-    gint i;
+  int w, h;
+  gint i;
 
-    if (width != NULL)
-        *width = 1;
-    if (height != NULL)
-        *height = 1;
-    if (font_buf != NULL)
-        g_memset (font_buf, 0, sizeof(guint8) * 65536);
-    for (i = 0; i < 128; i++)
-        if (charset_length (i) == 1 && g_unichar_isprint ((gunichar)i))
-          {
-            pango_layout_set_text (layout, (const char *)&i, 1);
-            pango_layout_get_pixel_size (layout, &w, &h);
-            if (width != NULL && *width < w)
-                *width = w;
-            if (height != NULL && *height < h)
-                *height = h;
-          }
+  if (width)
+    *width = 1;
+  if (height)
+    *height = 1;
+  if (font_buf)
+    g_memset (font_buf, 0, sizeof(guint8) * 65536);
+  for (i = 0; i < 128; i++)
+    if (charset_length (i) == 1 && g_unichar_isprint ((gunichar)i))
+      {
+        pango_layout_set_text (layout, (const char *)&i, 1);
+        pango_layout_get_pixel_size (layout, &w, &h);
+        if (width && *width < w)
+            *width = w;
+        if (height && *height < h)
+            *height = h;
+      }
 }
 
 
-/*  表示上の半角単位の文字幅を求める
+/*  ja:表示上の半角単位の文字幅を求める
       layout,レイアウト
         text,文字
        width,幅
     font_buf,バッファ
          RET,半角単位                                                       */
 gint
-charset_width (PangoLayout *layout, const gchar *text,
-                                            const gint width, guint8 *font_buf)
+charset_width (PangoLayout *layout,
+               const gchar *text,
+               const gint   width,
+               guint8      *font_buf)
 {
-    int w;
-    gint result;
-    gsize length;
-    gunichar c;
+  int w;
+  gint result;
+  gsize length;
+  gunichar c;
 
-    length = charset_length (*text);
-    c = g_utf8_get_char_validated (text, length);
-    if (!g_unichar_validate (c))
-        return 1;
-    if ((guint32)c < 65536)
-      {
-        if (length <= 1)
-            font_buf[c] = 1;
-        if (font_buf[c] != 0)
-            return font_buf[c];
-      }
-    pango_layout_set_text (layout, text, length);
-    pango_layout_get_pixel_size (layout, &w, NULL);
-    result = MAX ((w + width - 1) / width, 1);
-    if ((guint32)c < 65536)
-        font_buf[c] = result;
-    return result;
+  length = charset_length (*text);
+  c = g_utf8_get_char_validated (text, length);
+  if (!g_unichar_validate (c))
+    return 1;
+  if ((guint32)c < 65536)
+    {
+      if (length <= 1)
+        font_buf[c] = 1;
+      if (font_buf[c])
+         return font_buf[c];
+    }
+  pango_layout_set_text (layout, text, length);
+  pango_layout_get_pixel_size (layout, &w, NULL);
+  result = MAX ((w + width - 1) / width, 1);
+  if ((guint32)c < 65536)
+    font_buf[c] = result;
+  return result;
 }
 
 
-/*  文字の種類を返す
+/*  ja:文字の種類を返す
     text,文字
      RET,文字の種類                                                         */
 gint
 charset_block (const gchar *text)
 {
-    gint i;
-    gunichar c;
-    struct {
-        gunichar min,max;
-        guint type;
-    } type_range[] = {
+  gint i;
+  gunichar c;
+  struct
+  {
+    gunichar min,max;
+    guint type;
+  } type_range[] = {
         {0x000000, 0x00007f, CS_BASIC_LATIN},
         {0x000080, 0x0000ff, CS_LATIN_1_SUPPLEMENT},
         {0x000100, 0x00017f, CS_LATIN_EXTENDED_A},
@@ -238,11 +244,12 @@ charset_block (const gchar *text)
         {0x0e0000, 0x0e007f, CS_TAGS},
         {0x0e0100, 0x0e01ef, CS_VARIATION_SELECTORS_SUPPLEMENT},
         {0x0f0000, 0x0fffff, CS_SUPPLEMENTARY_PRIVATE_USE_AREA_A},
-        {0x100000, 0x10ffff, CS_SUPPLEMENTARY_PRIVATE_USE_AREA_B}};
+        {0x100000, 0x10ffff, CS_SUPPLEMENTARY_PRIVATE_USE_AREA_B},
+        {0,        0,        0}};
 
-    c = g_utf8_get_char (text);
-    for (i = 0; type_range[i].type != 0; i++)
-        if (type_range[i].min <= c && c <= type_range[i].max)
-            return type_range[i].type;
-    return 0;
+  c = g_utf8_get_char (text);
+  for (i = 0; type_range[i].type; i++)
+    if (type_range[i].min <= c && c <= type_range[i].max)
+      return type_range[i].type;
+  return 0;
 }
