@@ -23,6 +23,11 @@
 #include "tmaid.h"
 
 
+#ifdef __cplusplus
+extern "C" {
+#endif /* __cplusplus */
+
+
 #define charset_length(ch) (charset_leng[(gint)(guchar)(ch)])
 #define CS_BASIC_LATIN                               1
 #define CS_LATIN_1_SUPPLEMENT                        2
@@ -192,4 +197,9 @@ gint
 charset_block (const gchar *text);
 
 
+#ifdef __cplusplus
+}
+#endif /* __cplusplus */
+
+
 #endif
