@@ -23,6 +23,11 @@
 #include "tmaid.h"
 
 
+#ifdef __cplusplus
+extern "C" {
+#endif /* __cplusplus */
+
+
 typedef struct FindString_Tag
 {
   gboolean arrow;
@@ -70,4 +75,9 @@ gboolean
 find_dialog (FindString *fd);
 
 
+#ifdef __cplusplus
+}
+#endif /* __cplusplus */
+
+
 #endif
