@@ -23,6 +23,11 @@
 #include "tmaid.h"
 
 
+#ifdef __cplusplus
+extern "C" {
+#endif /* __cplusplus */
+
+
 /******************************************************************************
 *                                                                             *
 * ja:プロパティ関数群                                                         *
@@ -55,4 +60,9 @@ property_change (TmaidWindow *tmaid,
 gboolean property_dialog(FileType *ft);
 
 
+#ifdef __cplusplus
+}
+#endif /* __cplusplus */
+
+
 #endif
