@@ -23,6 +23,11 @@
 #include "tmaid.h"
 
 
+#ifdef __cplusplus
+extern "C" {
+#endif /* __cplusplus */
+
+
 /******************************************************************************
 *                                                                             *
 * ja:シグナル/イベント関数群(テキスト)                                        *
@@ -133,4 +138,9 @@ signal_destroy_window (GtkWidget *widget,
                        gpointer   user_data);
 
 
+#ifdef __cplusplus
+}
+#endif /* __cplusplus */
+
+
 #endif
